==================
Command-Line Usage
==================

shpkpr is mostly self-documenting, and documentation for any command or subcommand can be viewed by passing the ``--help`` parameter, e.g.

.. command-output:: shpkpr --help

For more detailed usage instructions see the sections linked below:

.. toctree::
   :maxdepth: 1

   configuration
   templates

   cmd_apps/index
   cmd_cron/index
